==> tutti-ui-swing-2.3-sources.jar: fr/ifremer/tutti/ui/swing/util/table/MoveToNextEditableRowAction.java <==
package fr.ifremer.tutti.ui.swing.util.table;

/*
 * #%L
 * Tutti :: UI
 * $Id: MoveToNextEditableRowAction.java 1063 2013-05-31 10:24:19Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/table/MoveToNextEditableRowAction.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JTable;
import java.awt.event.ActionEvent;

/**
 * Action to select next editable row in a table.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class MoveToNextEditableRowAction<M extends AbstractTuttiTableModel> extends AbstractSelectTableAction<M> {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(MoveToNextEditableRowAction.class);

    public static <M extends AbstractTuttiTableModel> MoveToNextEditableRowAction<M> newAction(M model, JTable table) {
        return new MoveToNextEditableRowAction<M>(model, table);
    }

    protected MoveToNextEditableRowAction(M model, JTable table) {
        super(model, table);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        int currentRow = getSelectedRow();
        int currentColumn = getSelectedColumn();

        if (log.isDebugEnabled()) {
            log.debug("Move to next row editable cell " +
                              getCellCoordinate(currentRow, currentColumn));
        }

        int rowCount = getRowCount();

        while (currentRow < rowCount) {

            // go to next cell
            currentRow++;
            boolean canSelect = true;

            // select next cell
            if (currentRow >= rowCount) {

                if (log.isDebugEnabled()) {
                    log.debug("No next row");
                }
                if (isCreateNewRow()) {

                    // create a new row in model
                    addNewRow();
                } else {
                    canSelect = false;
                }
            } else {
                canSelect = isCellEditable(currentRow, currentColumn);
            }

            if (canSelect) {
                doSelectCell(currentRow, currentColumn);

                break;
            } else {
                if (log.isDebugEnabled()) {
                    log.debug("Cell not editable at " +
                                      getCellCoordinate(currentRow, currentColumn));
                }
            }
        }
    }
}

==> tutti-ui-swing-2.3.1-sources.jar: fr/ifremer/tutti/ui/swing/util/table/MoveToNextEditableRowAction.java <==
package fr.ifremer.tutti.ui.swing.util.table;

/*
 * #%L
 * Tutti :: UI
 * $Id: MoveToNextEditableRowAction.java 1104 2013-06-12 07:45:06Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.3.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/table/MoveToNextEditableRowAction.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JTable;
import java.awt.event.ActionEvent;

/**
 * Action to select next editable row in a table.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class MoveToNextEditableRowAction<M extends AbstractTuttiTableModel> extends AbstractSelectTableAction<M> {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(MoveToNextEditableRowAction.class);

    public static <M extends AbstractTuttiTableModel> MoveToNextEditableRowAction<M> newAction(M model, JTable table) {
        return new MoveToNextEditableRowAction<M>(model, table);
    }

    protected MoveToNextEditableRowAction(M model, JTable table) {
        super(model, table);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        int currentRow = getSelectedRow();
        int currentColumn = getSelectedColumn();

        if (log.isDebugEnabled()) {
            log.debug("Move to next row editable cell " +
                              getCellCoordinate(currentRow, currentColumn));
        }

        int rowCount = getRowCount();

        // I commented the part of the code to skip the not editable cells (ref #2704)
//        while (currentRow < rowCount) {
        if (currentRow < rowCount) {
            // go to next cell
            currentRow++;
//            boolean canSelect = true;

            // select next cell
            if (currentRow >= rowCount) {

                if (log.isDebugEnabled()) {
                    log.debug("No next row");
                }
                if (isCreateNewRow()) {

                    // create a new row in model
                    addNewRow();
//                } else {
//                    canSelect = false;
                }
//            } else {
//                canSelect = isCellEditable(currentRow, currentColumn);
            }

//            if (canSelect) {
                doSelectCell(currentRow, currentColumn);

//                break;
//            } else {
//                if (log.isDebugEnabled()) {
//                    log.debug("Cell not editable at " +
//                                      getCellCoordinate(currentRow, currentColumn));
//                }
//            }
        }
    }
}
